==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PsProductCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: PsProductCond.java, v 0.1 2015-08-19 10:57
 */
public class PsProductCond extends PsMatchCampaignCond {

    private String id;
    private List<String> ids;

    private Boolean combined;

    private List<String> channelCodes;

    private String code;
    private List<String> codes;
    private String name;
    private String nameCn;

    private String primaryUpdateTime;

    private String updateTime;
    private String updateTimeEnd;

    private Boolean firstBuy = false;  // 是否首单

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public List<String> getCodes() {
        return codes;
    }

    public void setCodes(List<String> codes) {
        this.codes = codes;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameCn() {
        return nameCn;
    }

    public void setNameCn(String nameCn) {
        this.nameCn = nameCn;
    }

    public List<String> getIds() {
        return ids;
    }

    public void setIds(List<String> ids) {
        this.ids = ids;
    }

    public Boolean getCombined() {
        return combined;
    }

    public void setCombined(Boolean combined) {
        this.combined = combined;
    }

    public List<String> getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(List<String> channelCodes) {
        this.channelCodes = channelCodes;
    }


    public String getPrimaryUpdateTime() {
        return primaryUpdateTime;
    }

    public void setPrimaryUpdateTime(String primaryUpdateTime) {
        this.primaryUpdateTime = primaryUpdateTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

//    public void setUpdateTime(Date updateTime) {
//        this.updateTime = DateUtil.format(updateTime, DateUtil.DEFAULT_DATETIME_FORMAT);
//    }

    public String getUpdateTimeEnd() {
        return updateTimeEnd;
    }

    public void setUpdateTimeEnd(String updateTimeEnd) {
        this.updateTimeEnd = updateTimeEnd;
    }
//    public void setUpdateTimeEnd(Date updateTime) {
//        this.updateTimeEnd = DateUtil.format(updateTime, DateUtil.DEFAULT_DATETIME_FORMAT);
//    }

    public Boolean getFirstBuy() {
        return firstBuy;
    }

    public void setFirstBuy(Boolean firstBuy) {
        this.firstBuy = firstBuy;
    }

    @Override
    public String toString() {
        return "PsProductCond{" +
                "id='" + id + '\'' +
                ", ids=" + ids +
                ", combined=" + combined +
                ", channelCodes=" + channelCodes +
                ", code='" + code + '\'' +
                ", codes=" + codes +
                ", name='" + name + '\'' +
                ", nameCn='" + nameCn + '\'' +
                ", primaryUpdateTime='" + primaryUpdateTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", updateTimeEnd='" + updateTimeEnd + '\'' +
                ", firstBuy=" + firstBuy +
                '}';
    }
}

==> pegasus-merchandise-api-1.4.9-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PsProductCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: PsProductCond.java, v 0.1 2015-08-19 10:57
 */
public class PsProductCond extends PsMatchCampaignCond {

    private String id;
    private List<String> ids;

    private Boolean combined;

    private List<String> channelCodes;

    private String code;
    private List<String> codes;
    private String name;
    private String nameCn;

    private String primaryUpdateTime;

    private String updateTime;
    private String updateTimeEnd;
    private Boolean isStock;
    private String memberCode;      // 会员编码
    private String channelCode;     // 渠道编码

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public List<String> getCodes() {
        return codes;
    }

    public void setCodes(List<String> codes) {
        this.codes = codes;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameCn() {
        return nameCn;
    }

    public void setNameCn(String nameCn) {
        this.nameCn = nameCn;
    }

    public List<String> getIds() {
        return ids;
    }

    public void setIds(List<String> ids) {
        this.ids = ids;
    }

    public Boolean getCombined() {
        return combined;
    }

    public void setCombined(Boolean combined) {
        this.combined = combined;
    }

    public List<String> getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(List<String> channelCodes) {
        this.channelCodes = channelCodes;
    }


    public String getPrimaryUpdateTime() {
        return primaryUpdateTime;
    }

    public void setPrimaryUpdateTime(String primaryUpdateTime) {
        this.primaryUpdateTime = primaryUpdateTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

//    public void setUpdateTime(Date updateTime) {
//        this.updateTime = DateUtil.format(updateTime, DateUtil.DEFAULT_DATETIME_FORMAT);
//    }

    public String getUpdateTimeEnd() {
        return updateTimeEnd;
    }

    public void setUpdateTimeEnd(String updateTimeEnd) {
        this.updateTimeEnd = updateTimeEnd;
    }
//    public void setUpdateTimeEnd(Date updateTime) {
//        this.updateTimeEnd = DateUtil.format(updateTime, DateUtil.DEFAULT_DATETIME_FORMAT);
//    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Boolean getIsStock() {
        return isStock;
    }

    public void setIsStock(Boolean isStock) {
        this.isStock = isStock;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    @Override
    public String toString() {
        return "PsProductCond{" +
                "id='" + id + '\'' +
                ", ids=" + ids +
                ", combined=" + combined +
                ", channelCodes=" + channelCodes +
                ", code='" + code + '\'' +
                ", codes=" + codes +
                ", name='" + name + '\'' +
                ", nameCn='" + nameCn + '\'' +
                ", primaryUpdateTime='" + primaryUpdateTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", updateTimeEnd='" + updateTimeEnd + '\'' +
                ", channelCode='" + channelCode + '\'' +
                ", memberCode='" + memberCode + '\'' +
                '}';
    }
}
